[project]
name = "{{ name }}"
version = "0.1.0"
description = "{{ description }}"
requires-python = ">=3.12"

dependencies = [
    "macsdk",
    "python-dotenv>=1.0.0",
]
{% if uv_sources %}
{{ uv_sources }}
{% endif %}

[dependency-groups]
dev = [
    "pytest>=8.0",
    "pytest-asyncio>=0.24",
    "ruff>=0.8",
    "mypy>=1.0",
]

[project.scripts]
{{ script_name }} = "{{ agent_slug }}.cli:main"

[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[tool.hatch.build.targets.wheel]
packages = ["src/{{ agent_slug }}"]

[tool.pytest.ini_options]
testpaths = ["tests"]
asyncio_mode = "auto"
