# Byte-compiled / optimized / DLL files
__pycache__/
*.py[cod]
*$py.class

# C extensions
*.so

# Distribution / packaging
.Python
build/
develop-eggs/
dist/
downloads/
eggs/
.eggs/
lib/
lib64/
parts/
sdist/
var/
wheels/
*.egg-info/
.installed.cfg
*.egg

# Virtual environments
.venv/
venv/
ENV/
env/

# IDE
.idea/
.vscode/
*.swp
*.swo
*~

# Environment variables
.env
.env.local
.env.*.local

# pytest
.pytest_cache/
.coverage
htmlcov/

# mypy
.mypy_cache/

# ruff
.ruff_cache/

# Jupyter
.ipynb_checkpoints/
{% if with_rag %}

# ChromaDB vector store
chroma_db/

# LLM cache
.macsdk_llm_cache.db

# Downloaded certificates
.cache/
{% endif %}

# OS files
.DS_Store
Thumbs.db

# Project specific
*.log

